#!/usr/bin/env python

"""
    batchps.py
    
    Convert sets of images using sk2ps.
"""

try:

    import cmdsyntax
    use_cmdsyntax = 1

except ImportError:

    use_cmdsyntax = 0

import glob, os, popen2, string, sys


def read_cmdsyntax_input(syntax, argv):

    syntax_obj = cmdsyntax.Syntax(syntax)
    
    matches = syntax_obj.get_args(argv[1:])
    
    if matches == [] and cmdsyntax.use_GUI() != None:
    
        form = cmdsyntax.Form("Convert files", syntax_obj)
        
        matches = form.get_args()
    
    return matches


def read_input(argv):

    # Assume that all the arguments from the second onwards are to be used.
    if len(argv) > 1:
    
        return [{"input files": argv[1:]}]
    
    else:
    
        return []


if __name__ == "__main__":

    syntax = "--help | ( <input files> ... )"
    
    if use_cmdsyntax == 1:
    
        matches = read_cmdsyntax_input(syntax, sys.argv)
    
    else:
    
        matches = read_input(sys.argv)
    
    if len(matches) > 0:
    
        # Take the first match.
        match = matches[0]
    
    else:
    
        match = None
    
    if match is None or match.has_key("help"):
    
        print "Usage: %s %s" % (sys.argv[0], syntax)
        print
        print "Convert drawings to PostScript files, giving the output files the"
        print '".ps" suffix.'
        print
        sys.exit()
    
    # Read the parameters passed into the match dictionary.
    specifications = match["input files"]
    
    for spec in specifications:
    
        # Expand each specification.
        paths = glob.glob(spec)
        
        for path in paths:
        
            # Find the filename and the directory containing it.
            (directory, file) = os.path.split(path)
            
            at = string.rfind(file, ".")
            
            if at != -1:
            
                # Replace the suffix with .ps.
                newfile = file[:at] + ".ps"
            
            else:
            
                # Add the .ps suffix to the filename.
                newfile = file + ".ps"
            
            # Call the sk2ps tool with the relevant files.
            so, si, se = popen2.popen3( "sk2ps %s %s" % (
                    os.path.join(directory, file),
                    os.path.join(directory, newfile)
                ) )
            
            so.read()
            se.read()
    
    # Exit
    sys.exit()
